# Test Coverage Report: excluded packages and modules

Generated: Thu 2012-03-01 14:21 CST

These packages and modules were excluded from the coverage analysis in `django.conf.settings.COVERAGE_MODULE_EXCLUDES` or they do not contain any executable statements:

- permission.__init__
- permission.backends.__init__
- permission.decorators.__init__
- permission.handlers.__init__
- permission.tests

Back to index.